# hclib

[![Known Vulnerabilities](https://snyk.io/test/github/neelkamath/hclib/badge.svg?targetFile=requirements.txt)](https://snyk.io/test/github/neelkamath/hclib?targetFile=requirements.txt)
[![pypi-v](https://img.shields.io/pypi/v/hclib.svg)](https://pypi.python.org/pypi/hclib)

This is a library to connect to [hack.chat](https://hack.chat/).

Get it: `pip3 install hclib`

To view documentation:
1. Start the REPL:
    - Windows: `python`
    - Other: `python3`
1. Access documentation:
    ```python
    import hclib
    help(hclib)
    ```

# Contributing

- [Code of Conduct](CODE_OF_CONDUCT.md)

## Installation

### Prerequisites

- [Python 3 or higher](https://www.python.org/downloads/)

### Installing

`git clone https://github.com/neelkamath/hclib.git`

## Usage

- Windows: `python hclib.py`
- Other: `python3 hclib.py`

# License

This project is under the [MIT License](LICENSE).
